Monty Python's Flying Circus: Just the Words - Episode 2

# Episode Two: Sex and violence

Flying Sheep
French lecture on sheep-aircraft
A man with three buttocks
A man with two noses
Musical mice
Marriage guidance counsellor
The wacky queen
Working-class playwright
A Scotsman on a horse
The wrestling epilogue
The mouse problem

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A man appears on the top of a sand dune some way away. He loks in direction of camera and runs towards it. He disappears on top of a closer dune and continues towards camera disappearing again into a dip. This time while he is out of sight, the sound of him running is the sound of someone running along a prison corridor, followed by a big door opening and closing.He appears again only two sand dunes away. Still running towards camera he disappears again from sight. This time there is a loud metallic series of sounds followed by a pig squealing. He appears over the nearest dune and runs up to camera.
It's Man | It's...
Voice Over | Monty Python's Flying Circus.
| These words are followed by various strange images, possibly connected with the stretching of owls, and proceeding from a bizarre Amerian immigrant's feveral brain. At the end of this expensive therapy: CAPTION: 'PART 2' CAPTION: 'SHEEP' A small set of a gate in the country overlooking a field. A real rustic in smock and floppy hat is leaning on the gate. A city gent on holiday appears behind him. Off-screen baa-ing noises throughout.
City Gent | Good afternoon.
Rustic | Afternoon.
City Gent | A lovely day isn't it.
Rustic | Eh, 'tis that.
City Gent | You here on holiday or...?
Rustic | Nope, I live 'ere.
City Gent | Oh, jolly good too. (surveys field; he looks puzzled) I say, those are sheep aren't they?
Rustic | Ar.
City Gent | Yes, yes of course, I thought so...only...er why are they up in the trees?
Rustic | A fair question and one that in recent weeks has been much on my mind. It's my considered opinion that they're nesting.
City Gent | Nesting?
Rustic | Ar.
City Gent | Like birds?
Rustic | Ar. Exactly. Birds is the key to the whole problem. It's my belief that these sheep are laborin' under the misapprehension that they're birds. Observe their behavior. Take for a start the sheeps' tendency to 'op about the field on their back legs. (off-screen baa-ing) Now witness their attempts to fly from tree to tree. Notice that they do not so much fly as...plummet. (sound of sheep plummeting) Observe for example that ewe in that oak tree. She is clearly trying to teach her lamb to fly. (baaaaaa...thump) Talk about the blind leading the blind.
City Gent | But why do they think they're birds?
Rustic | Another fair question. One thing is for sure; a sheep is not a creature of the air. They have enormous difficulty in the comparatively simple act of perchin'. (crash) As you see. As for flight, its body is totally unadapted to the problems of aviation. Trouble is, sheep are very dim. Once they get an idea in their heads, there's no shifting it.
City Gent | But where did they get the idea from?
Rustic | From Harold. He's that sheep there over under the elm. He's that most dangerous of animals, a clever sheep. He's the ring-leader. He has realized that a sheep's life consists of standing around for a few months and then being eaten. And that's a depressing prospect for an ambitious sheep. He's patently hit on the idea of escape.
City Gent | Well why don't you just get rid of Harold?
Rustic | Because of the enormous commercial possibilities should he succeed.
| Two Frenchmen stand in front of a diagram of a sheep adapted for flying. They speak rapidly in French, much of it pseudo.
First Frenchman | Bonsoir - ici nous avons les diagrammes modernes d'un mouton anglo-français ... maintenant ... baa-aa, baa-aa... nous avons, dans la tête, le cabinc. Ici, on se trouve le petit capitaine Anglais, Monsieur Trubshawe.
Second Frenchman | Vive Brian, wherever you are.
First Frenchman | D'accord, d'accord. Maintenant, je vous présente mon collègue, le pouf célèbre, Jean-Brian Zatapathique.
| Transfers his moustache to Second Frenchman
Second Frenchman | Maintenant, le mouton ... le landing ... les wheels, bon.
| Opens diagram to show wheels on sheep's legs.
First Frenchman | Bon, les wheels, ici.
Second Frenchman | C'est formidable, n'est ce pas ... (unintelligibly indicates motor at rear of sheep)
First Frenchman | Les voyageurs ... les bagages ... ils sont ... ici!
| Triumphantly opens the rest of the diagram to reveal the whole brilliant arrangement. They run round flapping their arms and baa-ing. Cut to pepperpots in supermarket with off-screen interviewer.
First Pepperpot | Oh yes, we get a lot of French people round here.
Second Pepperpot | Ooh Yes.
Third Pepperpot | All over yes.
Interviewer | And how do you get on with these French people?
First Pepperpot | Oh very well.
Fourth Pepperpot | So do I.
Third Pepperpot | Me too.
First Pepperpot | Oh yes I like them. I mean, they think well don't they? I mean, be fair - Pascal.
Second Pepperpot | Blaise Pascal.
Third Pepperpot | Jean-Paul Sartre.
First Pepperpot | Yes, Voltaire.
Second Pepperpot | Ooh! - René Descartes.
| René Descartes is sitting thinking. Bubbles come from his head with 'thinks'. Suddenly he looks happy. In thought bubble appears 'I THINK THEREFORE I AM'. A large hand comes into the picture with a pin and pricks the thought bubble. It deflates and disappears. After a second René disappears too. Studio: Smart looking and confident announcer sitting at desk.
Announcer | And now for something completely different. A man with three buttocks!
| Interviewer and Arthur Frampton, in interview studio.
Interviewer | Good evening, I have with me, Mr Arthur Frampton, who has...Mr. Frampton, I understand that you...er...as it were...have er...well, let me put it another way...I believe Mr. Frampton that whereas most people have - er - two...two...you...you
Frampton | I'm sorry.
Interviewer | Ah yes, yes I see...Um, Are you quite comfortable?
Frampton | Yes fine, thank you.
Interviewer | (takes a quick glance at Frampton's bottom) Er, Mr Frampton... vis-à-vis...your...rump.
Frampton | I beg your pardon?
Interviewer | Er, your rump.
Frampton | What?
Interviewer | Your posterior....derriere...sit upon.
Frampton | What's that?
Interviewer | (whispers) ...Buttocks.
Frampton | Oh, me bum!
Interviewer | Sshhh! Well Mr. Frampton I understand Mr Frampton, you have a... 50% bonus in the...in the region of what you said.
Frampton | I got three cheeks.
Interviewer | Yes, yes, Splendid, splendid. Well...we were wondering, Mr Frampton, if you...could...see your way clear...
Frampton | (seeing a camera moving round behind him) Here? What's that camera doing?
Interviewer | Er, nothing, nothing at all, sir. We were wondering if you could see your way clear...to giving us...a quick... a quick... visual... Mr Frampton, will you take your trousers down?
Frampton | What? (slapping away a hand from off-screen) 'Ere, get off! I'm not taking me trousers down on television. Who do you think I am?
Interviewer | Please take them down.
Frampton | No.
Interviewer | Just a little bit.
Frampton | No.
Interviewer | No, er ahem...(firmly) Now look here Mr Frampton... It's perfectly easy for somebody just to come along here to the BBC simply claiming... that they have a bit to spare in the botty department...but the point is Mr. Frampton... our viewers need proof.
Frampton | I've been on Persian Radio...Get off! Arthur Figgis knows I've got three buttocks.
Interviewer | How?
Frampton | We go cycling together.
| Cut to shot of two men riding tandem. The one behind (Graham) looks down, looks up and exclaims 'strewth'. Announcer's desk: confident announcer again.
Announcer | And now for something completely different. A man with three buttocks.
| Interview studio again.
Interviewer | Good evening, I have with me, Mr Arthur Frampton, who... Mr. Frampton - I understand that you, as it were...well, let me put it another way...I believe Mr. Frampton that whereas most people...didn't we do this just now?
Frampton | Er...yes.
Interviewer | Well why didn't you say so?
Frampton | I thought it was the continental version.
| Announcer's desk: confident announcer.
Announcer | And now for something completely the same - a man with three buttocks. (phone on desk rings - he answers it) Hullo? ...Oh, did we. (puts phone down; to camera) And now for something completely different. A man with three noses.
Off-screen Voice | He's not here yet!
Announcer | Two noses?
| Stock shot of audience of Woman's Institute type, applauding. A man flourishing a handferchief blows his nose. Then he puts his handkerchief inside his shirt and blows again. Stock shot of women applauding again.
Compère | Ladies and gentlemen isn't she just great eh, wasn't she just great. Ha, ha, ha, and she can run as fast as she can sing, ha, ha, ha. And I'm telling you - 'cos I know. No, only kidding. Ha, ha, ha. Seriously now, ladies and gentlemen, we have for you one of the most unique acts in the world today. He's...well I'll say no more, just let you see for yourselves...ladies and gentlemen, my very great priviledge to introduve Arthur Ewing, and his musical mice.
| Cut to Ewing
Ewing | Thank you, thank you, thank you, thank you. Ladies and gentlemen. I have in this box twenty-three white mice. Mice which have been painstakingly trained over the past few years, to squeak at a selected pitch. (he raises a mouse by its tail) This is E sharp... and this one is G. You get the general idea. Noe these mice are so arranged upon this rack, that when played in the correct order they will squeak 'The Bells of St Mary's'. Ladies and gentlemen, I give you on the mouse organ 'The Bells of St Mary's'. Thank you.
| He produces two mallets. He starts striking the mice while singing quietly 'The Bells of St Mary's'. Each downward stroke of the mallet brings a terribly squashing sound and the expiring squeak. It is quite clear that he is slaughtering the mice. The musical effect is poor. After the first few notes people are shouting 'Stop it, stop him someone, Oh my God'. He cheerfully takes a bow. He is hauled off by the floor manager. Cut to a man holding up cards saying 'Marriage Counsellor'. The counsellor sits behind a desk. He puts down the card and says:
Counsellor | Next!
| A little man enters, with a beautiful blond buxom wench, in the full bloom of her young womanhood (Carol Cleveland)
Man | Are you the marriage guidance counsellor?
Counsellor | Yes. Good morning
Man | Good morning, sir
Counsellor | (stares at the wife, fascinated) And good morning to you madam (pauses, he shrugs himself out of it, says to man...) Name?
Man | Mr and Mrs Arthur Pewtey, Pewtey.
Counsellor | (writes without looking down, just stares at the wife) And what is the name of your ravishing wife? (holds up hand) Wait. Don't tell me - it's something to do with moonlight - it goes with her eyes - it's soft and gentle, warm and yeilding, deeply lyrical and yet tender and frightened like a tiny whit rabbit
Man | It's Deirdre
Counsellor | Deirdre. What a beautiful name. What a beautiful, beautiful name (leans across and lightly brushes his hand accross the wife's cheek) And what seems to be the trouble with your marriage Mr Pewtey?
Man | Well, it all started about five years ago when we started going on holiday to Brighton together. Deirdre, that's my wife, has always been a jolly good companion to me and I never particularly anticipated any marital strife - indeed the very idea of consulting a professional marital adviser has always been of the greatest repugnance to me although far be it from me to impugn the nature of your trade or profession
| The counsellor and wife are not listening, fascinated by each other.
Counsellor | (realizing Pewtey has stopped) Do go on.
Man | Well, as I say, we've always been good friends, sharing the interests, the gardening and so on, the model aeroplanes, the sixpenny bottle for the holiday money, and indeed twice a month settling down in the evenings doing the accounts, something which, er, Deirdre, Deirdre that's my wife, er, particularly looked forward to on account of her feet (the counsellor has his face fantastically close to the wife's, as close that they could get without kissing) I should probably have said at the outset that I'm noted for having something of a sense of humour, although I have kept myself very much to myself over the last two years notwithstanding, as it were, and it's only as comparatively recently that I began to realize - well, er prehaps realize is not the correct word, er, imagine, imagine, that I was not the only thing in her life
Counsellor | (who is practically in a clinch with her) You suspected your wife?
Man | Well yes - at first, frankly yes (the counsellor points the wife to a screen; she goes behind it) Her behaviour did seem at the time to me, who after all was there to see, to be a little odd.
Counsellor | Odd?
Man | Yes well, I mean to a certain extent yes. I'm not by nature a suspicious person - far from it - though in fact I have something of a reputation as an after-dinner speaker, if you take my meaning....
| A piece of his wife's clothing comes over the top of the screen.
Counsellor | Yes I certainly do
| The wife's bra and panties come over the screen.
Man | Anyway in the area where I'm known people in fact know me extremely well....
Counsellor | (taking his jacket off) Oh yes. Would you hold this.
Man | Certainly yes (helps him with it; the counsellor continues to undress) Anyway, as I said, I decided to face up to the facts and stop beating about the bush or I'd never look myself in the bathroom mirror again.
Counsellor | (down to his shorts) Er, look would you mind running along for ten minutes? Make it half an hour.
Man | No, no, right-ho, fine. Yes I'll wait outside shall I?...(the cousellor has already gone behind the screen) Yes, well that's p'raps the best things. Yes. You've certainly put my mind at rest on one or two points, there.
| Exits through door. He is stopped by a deep southern American voice.
Southener | Now wait there stranger. A man can run and run for year after year until he realizes that what he's running from...is hisself
Man | Gosh.
Southener | A man's got to do what a man's got to do, and there ain't no sense in runnin'. Now you gotta turn, and you gotta fight, and you gotta hold your head up high.
Man | Yes!
Southener | Now you go back in there my son and be a man. Walk tall. (he exits)
Man | Yes, I will. I will. I've been pushed around long enough. This is it. This is your monent Arthur Pewtey - this is it Arthur Pewtey. At last you're a man! (open the door very determinedly) All right, Dierdre, come out of there
Counsellor | Go away
Man | Right. Right.
| He is hit on the head with a chicken by a man in a suit of armour.
| CAPTION: 'SO MUCH FOR PATHOS'
Voice Over | So much for pathos.
| Film leader: 9...8...7...6...31...6...Jimmy Greaves...4...3... Queen Victoria Film: the texture of the film reproduces as accurately as possible an animated Victorian photograph. Queen Victoria (Terry J) and Gladstone (Graham) are walking on the lawn in front of Osborne.
Voice Over | These historic pictures of Queen Victoria, taken in 1880 at Osborne show the Queen with Gladstone. This unique film provides a rare glimpse into the private world of a woman who ruled half the earth. The commentary, recorded on the earliest wax cylinders, is spoken by Alfred Lord Tennyson, the Poet Laureate.(Michael continues with jolly Amarican accent) Well hello, it's the wacky Queen again! (the Queen repeatedly nudges Gladstone in the ribs and chucks him under the ribs) And who's the other fella? It's Willie Gladstone! And when these two way-out wacky characters get together there's fun a-plenty. (they come up to a gardener with a hose pipe) And uh-oh! There's a hosepipe! This means trouble for somebody! (the Queen takes the hose and kicks the gardener; he falls over) Uh-oh, Charlie Gardener's fallen for that old trick. The Queen has put him in a heap of trouble! (the Queen turns the hose on Gladstone) Uh-oh that's onein the eye for Willie! (the Queen hands Gladstone the hose) Here you have a go! (she goes back to the tab and turns off the water) Well, doggone it, where's the water? (Gladstone examines the end of the hose; the water flow returns, spraying him) Uh-oh there it is, all over his face! (she lifts her skirts and runs as he chases her across the lawn; next we see the Queen painting a fence; Gladstone approaches from the other side) Well, hello, what's Britain's wacky Queen up to now? Well, she's certainly not sitting on the fence. She's painting it. Surely nothing can go wrong here? Uh-oh there's th PM coming back for more. (Gladstone walks into line with the end of the fence; the Queen daubs paint on him) And he certainly gets it! (he takes the bucket from her and empties it over her head; she kicks him; he falls through the fence) Well, that's one way to get the housework done!
| Cut to the Queen and Gladstone having tea on the lawn. She pushes a custard pie into his face. As he retaliates the picture freezes; the camera pulls back to reveal that it is a photo on the mantelpiece of a working-class sitting room. Cut to sitting room straight out of D. H. Lawrence. Mum, wiping her hand on her apron is ushering in a young man in a suit. They are a Northern couple.
Mum | Oh dad... look who's come to see us... it's our Ken.
Dad | (without looking up) Aye, and about bloody time if you ask me.
Ken | Aren't you pleased to see me, father?
Mum | (squeezing his arm reassuringly) Of course he's pleased to see you, Ken, he...
Dad | All right, woman, all right I've got a tongue in my head - I'll do 'talkin'. (looks at Ken distastefully) Aye ... I like yer fancy suit. Is that what they're wearing up in Yorkshire now?
Ken | It's just an ordinary suit, father... it's all I've got apart from the overalls.
| Dad turns away with an expression of scornful disgust.
Mum | How are you liking it down the mine, Ken?
Ken | Oh it's not too bad, mum... we're using some new tungsten carbide drills for the preliminary coal-face scouring operations.
Mum | Oh that sounds nice, dear...
Dad | Tungsten carbide drills! What the bloody hell's tungsten carbide drills?
Ken | It's something they use in coal-mining, father.
Dad | (mimicking) 'It's something they use in coal-mining, father'. You're all bloody fancy talk since you left London.
Ken | Oh not that again.
Mum | He's had a hard day dear... his new play opens at the National Theatre tomorrow.
Ken | Oh that's good.
Dad | Good! good? What do you know about it? What do you know about getting up at five o'clock in t'morning to fly to Paris... back at the Old Vic for drinks at twelve, sweating the day through press interviews, television interviews and getting back here at ten to wrestle with the problem of a homosexual nymphomaniac drug-addict involved in the ritual murder of a well known Scottish footballer. That's a full working day, lad, and don't you forget it!
Mum | Oh, don't shout at the boy, father.
Dad | Aye, 'ampstead wasn't good enough for you, was it? ... you had to go poncing off to Barnsley, you and yer coal-mining friends. (spits)
Ken | Coal-mining is a wonderful thing father, but it's something you'll never understand. Just look at you!
Mum | Oh Ken! Be careful! You know what he's like after a few novels.
Dad | Oh come on lad! Come on, out wi' it! What's wrong wi' me?... yet tit!
Ken | I'll tell you what's wrong with you. Your head's addled with novels and poems, you come home every evening reeling of Chateau La Tour...
Mum | Oh don't, don't.
Ken | And look what you've done to mother! She's worn out with meeting film stars, attending premieres and giving gala luncheons...
Dad | There's nowt wrong wi' gala luncheons, lad! I've had more gala luncheons than you've had hot dinners!
Mum | Oh please!
Dad | Aaaaaaagh! (clutches hands and sinks to knees)
Mum | Oh no!
Ken | What is it?
Mum | Oh, it's his writer's cramp!
Ken | You never told me about this...
Mum | No, we didn't like to, Kenny.
Dad | I'm all right! I'm all right, woman. Just get him out of here.
Mum | Oh Ken! You'd better go ...
Ken | All right. I'm going.
Dad | After all we've done for him...
Ken | (at the door) One day you'll realize there's more to life than culture... There's dirt, and smoke, and good honest sweat!
Dad | Get out! Get out! Get OUT! You ... LABOURER!
| Ken goes. Shocked silence. Dad goes to table and takes the cover off the typewriter.
Dad | Hey, you know, mother, I think there's a play there .... get t'agent on t'phone.
Mum | Aye I think you're right, Frank, it could express, it could express a vital theme of our age...
Dad | Aye.
| In the room beneath a man is standing on a chair banging on the ceiling with a broom.
Man | Oh shut up! (bang bang) Shut up! (they stop talking upstairs) Oh, that's better. (he climbs down and looks at the camera) And now for something completely different ... a man with three buttocks...
Mum and Dad | (from upstairs) We've done that!
| The man looks up slightly disconcerted.
Man | Oh all right. All right! A man with nine legs.
Voice Off | He ran away.
Man | Oh... Bloody Hell! Er ... a Scotsman on a horse!
| Cut to film of a Scotsman (John) riding up on a horse. He looks around, puzzled. Cut to stock film of Women's Institute audience applauding. Cut to the man with two noses (Graham); he puts a handkerchief to his elbow and we hear the sound of a nose being blown. Cut to Women's Institute audience applauding. Cut to cartoon of a flying sheep.
Voice Over | Harold! Come back, Harold! Harold! Come back, Harold! Oh, blast!
| The sheep is shot down by a cannon. Cut to a film of an audience of Indian ladies not applauding. CAPTION: 'THE EPILOGUE, A QUESTION OF BELIEF' Interview studio; interviewer in the middle. There is a monsignor in full clerical garb with skull-cap, and opposite him a tweed-suite, old Don figure.
Interviewer | Good evening, and welcome once again to the Epilogue. On the programme this evening we have Monsignor Edward Gay, visiting Pastoral Emissary of the Somerset Theological College and author of a number of books about belief, the most recent of which is the best seller 'My God'. And opposite him we have Dr Tom Jack: humanist, broadcaster, lecturer and author of the book 'Hello Sailor'. Tonight, instead of discussing the existence or non-existence of God, they have decided to fight for it. The existence, or non-existence, to be determined by two falls, two submissions, or a knockout. All right boys, let's get to it. Your master of ceremonies for this evening - Mr Arthur Waring.
| The partialpants move into a wrestling ring.
MC | Good evening ladies and gentlemen and welcome to a three-round contest of the Epilogue. Introducing on my right in the blue corner, appearing for Jehovah - the ever popular Monsignor Eddie Gay. (there are boos from the crowd) And on my left in the red corner - author of the books 'The Problems of Kierkegaard' and 'Hello Sailor' and visiting Professor of Modern Theological Philosophy at the University of East Anglia - from Wigan - Dr Tom Jack! (cheers; gong goes for the start)
| CAPTION: 'ROUND 1' They are real wrestlers. They throw each other about.
Interviewer | (commentating) Now Dr Jack's got a flying mare there. A flying mare there, and this is going to be a full body slam. A full body slam, and he's laying it in there, and he's standing back. Well .. there we are leaving the Epilogue for the moment, we'll be bringing you the result of this discussion later on in the programme.
Interviewer | Oh my God! (pulls out a revolver and shoots something off-screen)
| ANIMATION: We see a cowboy just having been shot. This leads into cartoon film, which include a carnivorous pram and music from Rodin's statue 'The Kiss'. Then a protest march appears carrying banners. Close in on banners which read: End Discrimination:Mice Is Nice; Ho Ho Ho Traps Must Go; Hands Off Mice; Repeal Anti-Mouse Laws Now; Kidderminster Young Methodists Resent Oppression: A Fair Deal For Mice Men. CAPTION: 'THE WORLD AROUND US' Photo of newspaper headlines: Pop Stars In Mouse Scandal; Peer Faces Rodent Charges. A man in a mouse skin running into police station with bag over head. CAPTION: 'THE MOUSE PROBLEM' Cut to a policeman leading a man in mouse costume into a police station. Photo of headline: Mouse Clubs On Increase. Cut to: photos of neon signs of clubs: Eek Eek Club; The Little White Rodent Room; Caerphilly A Go-Go. Cut to studio: ordinary grey-suited linkman.
Linkman | Yes. The Mouse Problem. This week 'The World Around Us' looks at the growing social phenomenon of Mice and Men. What makes a man want to be a mouse.
| Interviewer, Harold Voice, sitting facing a confessor. The confessor is badly lit and is turned away from camera.
Man | (very slowly and painfully) Well it's not a question of wanting to be a mouse... it just sort of happens to you. All of a sudden you realize... that's what you want to be. |
Interviewer | And when did you first notice these... shall we say... tendencies?
Man | Well... I was about seventeen and some mates and me went to a party, and, er... we had quite a lot to drink... and then some of the fellows there ... started handing ... cheese around ... and well just out of curiosity I tried a bit ... and well that was that.
Interviewer | And what else did these fellows do?
Man | Well some of them started dressing up as mice a bit ... and then when they'd got the costumes on they started ... squeaking.
Interviewer | Yes. And was that all?
Man | That was all.
Interviewer | And what was your reaction to this?
Man | Well I was shocked. But, er... gradually I came to feel that I was more at ease ... with other mice.
| Cut to linkman.
Linkman | A typical case, whom we shall refer to as Mr A, although his real name is this:
Voice Over | (and CAPTION:) ARTHUR JACKSON 32A MILTON AVENUE, HOUNSLOW, MIDDLESEX.
Linkman | What is it that attracts someone like mr. A to this way of life? I have with me a consultant psychiatrist.
| The camera pulls back to reveal the psychiatrist who places in front og himself a notice saying 'The Amazing Kargol And Janet'.
Kargol | Well, we've just heard a typical case history. I myself have over seven hundred similar histories, all fully documented. Would you care to choose one?
| Janet (Carol), dressed in a showgirl's outfit, enters and offers linkman the case histories fanned out like cards, with one more prominent than the others; he picks it out.
Kargol | (without looking) Mr Arthur Aldridge of Leamington.
Linkman | Well, that's amazing, amazing. Thank you, Janet. (chord; Janet postures and exits) Kargol, speaking as a psychiatrist as opposed to a conjuror...
Kargol | (disappointed) Oh...
Linkman | ...what makes certain men want to be mice?
Kargol | Well, we psychiatrist have found that over 8% of the population will always be mice, I mean, after all, there's something of the mouse in all of us. I mean, how many of us can honestly say that at one time or another he hasn't felt sexually attracted to mice. (linkman looks puzzeld) I know I have. I mean, most normal adolescents go through a stage of squeaking two or three times a day. Some youngsters on the other hand, are attracted to it by its very illegality. It's like murder - make a thing illegal and it acquires a mystique. (linkman looks increasingly embarrassed) Look at arson - I mean, how many of us can honestly say that at one time or another he hasn't set fire to some great public building. I know I have. (phone on desk rings; the linkman picks it up but does not answer it) The only way to bring the crime figures down is to reduce the number of offences - get it out in the open - I know I have.
Linkman | (replacing phone) The Amazing Kargol And Janet. What a lot of people don't realize is that a mouse, once accepted, can fulfil a very useful role in society. Indeed there are examples throughout history of famous men now known to have been mice.
| Cut to julius Caesar on beach. He shouts 'Veni Vidi, Vici'. Then he adds a furtive squeak. Napoleon pulls slice of cheese out of jacket and bites into it. Cut to Linkman
Linkman | And, of course, Hillaire Belloc. But what is the attitude...
| Cut to man in a Viking helmet.
Viking | (Eric Idle) ... of the man in the street towards...
Linkman | ... this growing social problem?
| Vox pops films.
Window Cleaner | Clamp down on them.
Off-screen Voice | How?
Window Cleaner | I'd strangle them.
Stockbroker | Well speaking as a member of the Stock Exchange I would suck their brains out with a straw, sell the widows and orphans and go into South American Zinc.
Man | Yeh I'd, er, stuff sparrows down their throats, er, until the beaks stuck out through the, er, stomach walls.
Accountant | Oh well I'm a chartered accountant, and consequently too boring to be of interest.
Vicar | I feel that these poor unfortunate people should be free to live the lives of their own choice.
Porter | I'd split their nostrils open with a boat hook, I think.
Man | Well I mean, they can't help it, can they? But, er, there's nothing you can do about it. So er, I'd kill 'em.
| Cut to linkman.
Linkman | Clearly the British public's view is a hostile one.
Voice Over | (and CAPTION:) 'HOSTILE'
Linkman | But perhaps this is because so little is generally known of these mice men. We have some film now taken of one of the notorious weekend mouse parties, where these disgusting little perverts meet.
| Cut to exterior house (night). The blinds are drawn so that only shadows of enormous mice can be seen, holding slices of cheese and squeaking.
Linkman's Voice | Mr A tells us what actually goes on at these mouse parties.
| Cut to Mr A.
Mr A | Well first of all you get shown to your own private hole in the skirting board... then you put the mouse skin on... then you scurry into the main room, and perhaps take a run in the wheel.
Linkman | The remainder of this film was taken secretly at one of these mouse parties by a BBC cameraman posing as a vole. As usual we apologize for the poor quality of the film.
| Very, poor quality film, shadowy shapes, the odd mouse glimpsed.
Mr A's Voice | Well, er, then you steal some cheese, Brie or Camembert, or Cheddar or Gouda, if you're on the harder stuff. You might go and see one of the blue cheese films... there's a big clock in the middle of the room, and about 12:50 you climb up it and then ...eventually, it strikes one... and you all run down.
| Cut to a large matron with apron and cawing knife.
Linkman's Voice | And what's that?
Mr A's Voice | That's the farmer's wife.
| Cut to the linkman at desk.
Linkman | Perhaps we need to know more of these mice men before we can really judge them. Perhaps not. Anyway, our thirty minutes are up.
| Sound of baa-ing. The linkman looks up in air, looks startled, pulls a gun from under the desk and fires in the air. The body of a sheep falls to the floor.
Linkman | Goodnight.
| CAPTION: 'SEX AND VIOLENCE' WAS CONCIEVED, WRITTEN AND PERFORMED BY:... (CREDITS)'
Voice Over | And here is the result of the Epilogue: God exists by two falls to a submission